#: The vortex name for the Server service
peekServerName = "peek-server"

#: The vortex name for the Client service
peekClientName = "peek-client"

#: The vortex name for the Agent service
peekAgentName = "peek-agent"

#: The vortex name for the Worker service
peekWorkerName = "peek-worker"

#: The vortex name for the Mobile device/browser clients
peekMobileName = "peek-mobile"

#: The vortex name for the Desktop browser clients
peekDesktopName = "peek-desktop"

#: The vortex name for the Admin browser client
peekAdminName = "peek-admin"
